Package: ggstats
Type: Package
Title: Extension to 'ggplot2' for Plotting Stats
Version: 0.13.0
Authors@R: c(
    person(
      "Joseph", "Larmarange", ,
      "joseph@larmarange.net",
      role = c("aut", "cre"),
      comment = c(ORCID = "0000-0001-7097-700X")
    )
  )
Description: Provides new statistics, new geometries and new positions for 
    'ggplot2' and a suite of functions to facilitate the creation of 
    statistical plots.
License: GPL (>= 3)
URL: https://larmarange.github.io/ggstats/,
        https://github.com/larmarange/ggstats
BugReports: https://github.com/larmarange/ggstats/issues
Depends: R (>= 4.2)
Imports: cli, dplyr, forcats, ggplot2 (>= 4.0.0), lifecycle, patchwork,
        purrr, rlang, scales, stats, stringr, utils, tidyr
Suggests: betareg, broom, broom.helpers (>= 1.20.0), emmeans, glue,
        gtsummary, knitr, labelled (>= 2.11.0), reshape, rmarkdown,
        nnet, parameters, pscl, testthat (>= 3.0.0), spelling, survey,
        survival, vdiffr
Encoding: UTF-8
RoxygenNote: 7.3.3
Config/testthat/edition: 3
Language: en-US
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2026-03-06 13:00:41 UTC; josep
Author: Joseph Larmarange [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-7097-700X>)
Maintainer: Joseph Larmarange <joseph@larmarange.net>
Repository: CRAN
Date/Publication: 2026-03-06 13:40:02 UTC
