# Generated by roxygen2: do not edit by hand

S3method(round_any,POSIXct)
S3method(round_any,numeric)
export(GeomConnector)
export(PositionDiverging)
export(PositionLikert)
export(StatCross)
export(StatProp)
export(StatWeightedMean)
export(augment_chisq_add_phi)
export(auto_contrast)
export(compute_cascade)
export(geom_bar_connector)
export(geom_connector)
export(geom_diverging)
export(geom_diverging_text)
export(geom_likert)
export(geom_likert_text)
export(geom_prop_bar)
export(geom_prop_connector)
export(geom_prop_text)
export(geom_pyramid)
export(geom_pyramid_text)
export(geom_stripped_cols)
export(geom_stripped_rows)
export(ggcascade)
export(ggcoef_compare)
export(ggcoef_dodged)
export(ggcoef_faceted)
export(ggcoef_model)
export(ggcoef_multicomponents)
export(ggcoef_multinom)
export(ggcoef_plot)
export(ggcoef_table)
export(gglikert)
export(gglikert_data)
export(gglikert_side)
export(gglikert_stacked)
export(ggsurvey)
export(hex_bw)
export(hex_bw_threshold)
export(label_number_abs)
export(label_percent_abs)
export(likert_pal)
export(pal_extender)
export(plot_cascade)
export(position_diverging)
export(position_likert)
export(round_any)
export(scale_colour_extended)
export(scale_fill_extended)
export(scale_fill_likert)
export(signif_stars)
export(stat_cross)
export(stat_prop)
export(stat_weighted_mean)
export(symmetric_limits)
export(weighted.median)
export(weighted.quantile)
export(weighted.sum)
import(ggplot2)
importFrom(dplyr,.data)
importFrom(dplyr,sym)
importFrom(ggplot2,after_scale)
importFrom(ggplot2,after_stat)
importFrom(lifecycle,deprecate_soft)
importFrom(lifecycle,deprecate_stop)
importFrom(lifecycle,deprecate_warn)
importFrom(lifecycle,deprecated)
importFrom(scales,percent)
importFrom(stats,weighted.mean)
importFrom(stats,weights)
importFrom(utils,modifyList)
