## Test environments

* local R installation: R-4.4.0 (windows)
* mac OS (on github actions): R-release
* windows (on github actions): R-release
* ubuntu (on github actions): R-devel, R-release, R-oldrel-1

cf. https://github.com/larmarange/ggstats/actions

## R CMD check results

0 errors | 0 warnings | 0 note

## revdepcheck results

We checked 4 reverse dependencies (3 from CRAN + 1 from Bioconductor), comparing R CMD check results across CRAN and dev versions of this package.

 * We saw 0 new problems
 * We failed to check 0 packages
