# broom.helpers

<details>

* Version: 
* GitHub: https://github.com/larmarange/ggstats
* Source code: NA
* Number of recursive dependencies: 0

</details>

## Error before installation

### Devel

```

  Des versions binaires sont disponibles mais les versions des sources
  sont plus récentes:
          binary  source needs_compilation
DT          0.32    0.33             FALSE
htmltools  0.5.8 0.5.8.1              TRUE
TMB       1.9.10  1.9.11              TRUE

  Binaries will be installed
le package 'abind' a été décompressé et les sommes MD5 ont été vérifiées avec succés
...
le package 'readr' a été décompressé et les sommes MD5 ont été vérifiées avec succés
le package 'relimp' a été décompressé et les sommes MD5 ont été vérifiées avec succés
le package 'rematch2' a été décompressé et les sommes MD5 ont été vérifiées avec succés
le package 'reshape2' a été décompressé et les sommes MD5 ont été vérifiées avec succés
le package 'rex' a été décompressé et les sommes MD5 ont été vérifiées avec succés
le package 'rlang' a été décompressé et les sommes MD5 ont été vérifiées avec succés
le package 'rmarkdown' a été décompressé et les sommes MD5 ont été vérifiées avec succés
le package 'rngWELL' a été décompressé et les sommes MD5 ont été vérifiées avec succés
le package 'rpart' a été décompressé et les sommes MD5 ont été vérifiées avec succés
le package 'rprojroot' a été décompressé et les sommes MD5 ont été vérifiées avec succés


Avis : impossible d'accéder à l'index de l'entrepôt https://bioconductor.org/packages/3.18/bioc/bin/windows/contrib/4.4:
  impossible d'ouvrir l'URL 'https://bioconductor.org/packages/3.18/bioc/bin/windows/contrib/4.4/PACKAGES'
Avis : impossible d'accéder à l'index de l'entrepôt https://bioconductor.org/packages/3.18/bioc/bin/windows/contrib/4.4:
  impossible d'ouvrir l'URL 'https://bioconductor.org/packages/3.18/bioc/bin/windows/contrib/4.4/PACKAGES'
Avis : impossible d'accéder à l'index de l'entrepôt https://bioconductor.org/packages/3.18/data/annotation/bin/windows/contrib/4.4:
  impossible d'ouvrir l'URL 'https://bioconductor.org/packages/3.18/data/annotation/bin/windows/contrib/4.4/PACKAGES'
Avis : impossible d'accéder à l'index de l'entrepôt https://bioconductor.org/packages/3.18/data/annotation/bin/windows/contrib/4.4:
  impossible d'ouvrir l'URL 'https://bioconductor.org/packages/3.18/data/annotation/bin/windows/contrib/4.4/PACKAGES'
Avis : impossible d'accéder à l'index de l'entrepôt https://bioconductor.org/packages/3.18/data/experiment/bin/windows/contrib/4.4:
  impossible d'ouvrir l'URL 'https://bioconductor.org/packages/3.18/data/experiment/bin/windows/contrib/4.4/PACKAGES'
...
Avis : impossible d'accéder à l'index de l'entrepôt https://bioconductor.org/packages/3.18/data/experiment/bin/windows/contrib/4.4:
  impossible d'ouvrir l'URL 'https://bioconductor.org/packages/3.18/data/experiment/bin/windows/contrib/4.4/PACKAGES'
Avis : impossible d'accéder à l'index de l'entrepôt https://bioconductor.org/packages/3.18/workflows/bin/windows/contrib/4.4:
  impossible d'ouvrir l'URL 'https://bioconductor.org/packages/3.18/workflows/bin/windows/contrib/4.4/PACKAGES'
Avis : impossible d'accéder à l'index de l'entrepôt https://bioconductor.org/packages/3.18/workflows/bin/windows/contrib/4.4:
  impossible d'ouvrir l'URL 'https://bioconductor.org/packages/3.18/workflows/bin/windows/contrib/4.4/PACKAGES'
Avis : impossible d'accéder à l'index de l'entrepôt https://bioconductor.org/packages/3.18/books/bin/windows/contrib/4.4:
  impossible d'ouvrir l'URL 'https://bioconductor.org/packages/3.18/books/bin/windows/contrib/4.4/PACKAGES'
Avis : impossible d'accéder à l'index de l'entrepôt https://bioconductor.org/packages/3.18/books/bin/windows/contrib/4.4:
  impossible d'ouvrir l'URL 'https://bioconductor.org/packages/3.18/books/bin/windows/contrib/4.4/PACKAGES'


```
### CRAN

```

  Des versions binaires sont disponibles mais les versions des sources
  sont plus récentes:
          binary  source needs_compilation
DT          0.32    0.33             FALSE
htmltools  0.5.8 0.5.8.1              TRUE
TMB       1.9.10  1.9.11              TRUE

  Binaries will be installed
le package 'abind' a été décompressé et les sommes MD5 ont été vérifiées avec succés
...
le package 'readr' a été décompressé et les sommes MD5 ont été vérifiées avec succés
le package 'relimp' a été décompressé et les sommes MD5 ont été vérifiées avec succés
le package 'rematch2' a été décompressé et les sommes MD5 ont été vérifiées avec succés
le package 'reshape2' a été décompressé et les sommes MD5 ont été vérifiées avec succés
le package 'rex' a été décompressé et les sommes MD5 ont été vérifiées avec succés
le package 'rlang' a été décompressé et les sommes MD5 ont été vérifiées avec succés
le package 'rmarkdown' a été décompressé et les sommes MD5 ont été vérifiées avec succés
le package 'rngWELL' a été décompressé et les sommes MD5 ont été vérifiées avec succés
le package 'rpart' a été décompressé et les sommes MD5 ont été vérifiées avec succés
le package 'rprojroot' a été décompressé et les sommes MD5 ont été vérifiées avec succés


Avis : impossible d'accéder à l'index de l'entrepôt https://bioconductor.org/packages/3.18/bioc/bin/windows/contrib/4.4:
  impossible d'ouvrir l'URL 'https://bioconductor.org/packages/3.18/bioc/bin/windows/contrib/4.4/PACKAGES'
Avis : impossible d'accéder à l'index de l'entrepôt https://bioconductor.org/packages/3.18/bioc/bin/windows/contrib/4.4:
  impossible d'ouvrir l'URL 'https://bioconductor.org/packages/3.18/bioc/bin/windows/contrib/4.4/PACKAGES'
Avis : impossible d'accéder à l'index de l'entrepôt https://bioconductor.org/packages/3.18/data/annotation/bin/windows/contrib/4.4:
  impossible d'ouvrir l'URL 'https://bioconductor.org/packages/3.18/data/annotation/bin/windows/contrib/4.4/PACKAGES'
Avis : impossible d'accéder à l'index de l'entrepôt https://bioconductor.org/packages/3.18/data/annotation/bin/windows/contrib/4.4:
  impossible d'ouvrir l'URL 'https://bioconductor.org/packages/3.18/data/annotation/bin/windows/contrib/4.4/PACKAGES'
Avis : impossible d'accéder à l'index de l'entrepôt https://bioconductor.org/packages/3.18/data/experiment/bin/windows/contrib/4.4:
  impossible d'ouvrir l'URL 'https://bioconductor.org/packages/3.18/data/experiment/bin/windows/contrib/4.4/PACKAGES'
...
Avis : impossible d'accéder à l'index de l'entrepôt https://bioconductor.org/packages/3.18/data/experiment/bin/windows/contrib/4.4:
  impossible d'ouvrir l'URL 'https://bioconductor.org/packages/3.18/data/experiment/bin/windows/contrib/4.4/PACKAGES'
Avis : impossible d'accéder à l'index de l'entrepôt https://bioconductor.org/packages/3.18/workflows/bin/windows/contrib/4.4:
  impossible d'ouvrir l'URL 'https://bioconductor.org/packages/3.18/workflows/bin/windows/contrib/4.4/PACKAGES'
Avis : impossible d'accéder à l'index de l'entrepôt https://bioconductor.org/packages/3.18/workflows/bin/windows/contrib/4.4:
  impossible d'ouvrir l'URL 'https://bioconductor.org/packages/3.18/workflows/bin/windows/contrib/4.4/PACKAGES'
Avis : impossible d'accéder à l'index de l'entrepôt https://bioconductor.org/packages/3.18/books/bin/windows/contrib/4.4:
  impossible d'ouvrir l'URL 'https://bioconductor.org/packages/3.18/books/bin/windows/contrib/4.4/PACKAGES'
Avis : impossible d'accéder à l'index de l'entrepôt https://bioconductor.org/packages/3.18/books/bin/windows/contrib/4.4:
  impossible d'ouvrir l'URL 'https://bioconductor.org/packages/3.18/books/bin/windows/contrib/4.4/PACKAGES'


```
